summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyselector.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:01:10 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:01:10 -0600
commita6000c6f2f1a03b34f15d1948f63f0c894f09451 (patch)
tree59a9994e4bb71bc5a74704773e677f2d2474c017 /kmymoney2/widgets/kmymoneyselector.h
parentdb89d6f6d944825a20ce69bb11c23b19b2935164 (diff)
downloadkmymoney-a6000c6f2f1a03b34f15d1948f63f0c894f09451.tar.gz
kmymoney-a6000c6f2f1a03b34f15d1948f63f0c894f09451.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kmymoney2/widgets/kmymoneyselector.h')
-rw-r--r--kmymoney2/widgets/kmymoneyselector.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmymoney2/widgets/kmymoneyselector.h b/kmymoney2/widgets/kmymoneyselector.h
index 0a4ac8b..f50e404 100644
--- a/kmymoney2/widgets/kmymoneyselector.h
+++ b/kmymoney2/widgets/kmymoneyselector.h
@@ -28,7 +28,7 @@ class TQHBoxLayout;
// ----------------------------------------------------------------------------
// KDE Includes
-class KListView;
+class TDEListView;
// ----------------------------------------------------------------------------
// Project Includes
@@ -137,9 +137,9 @@ public:
void setSelected(const TQString& id, const bool state = false);
/**
* Return a pointer to the KListView object
*/
- KListView* listView(void) const { return m_listView; };
+ TDEListView* listView(void) const { return m_listView; };
/**
* This method selects/deselects all items that
@@ -201,7 +201,7 @@ public:
/**
* This method creates a new selectable object depending on the
* selection mode. This is either a KListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode
*
* @note The new item will be the first one in the selection
@@ -217,7 +217,7 @@ public:
/**
* This method creates a new selectable object depending on the
* selection mode. This is either a KListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode.
* In contrast to the above method, the parent is always the view.
*
@@ -362,7 +362,7 @@ protected slots:
void slotShowSelected(void);
/**
* This slot is connected to the KListView executed signal
*/
void slotItemSelected(TQListViewItem *it_v);
@@ -375,7 +375,7 @@ protected slots:
void slotListRightMouse(TQListViewItem* it_v, const TQPoint& p, int /* col */);
protected:
- KListView* m_listView;
+ TDEListView* m_listView;
TQStringList m_itemList;
TQString m_baseName;
TQListView::SelectionMode m_selMode;
@@ -137,9 +137,9 @@ public:
void setSelected(const TQString& id, const bool state = false);
/**
- * Return a pointer to the KListView object
+ * Return a pointer to the TDEListView object
*/
@@ -201,7 +201,7 @@ public:
/**
* This method creates a new selectable object depending on the
- * selection mode. This is either a KListViewItem for single
+ * selection mode. This is either a TDEListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode
*
@@ -217,7 +217,7 @@ public:
/**
* This method creates a new selectable object depending on the
- * selection mode. This is either a KListViewItem for single
+ * selection mode. This is either a TDEListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode.
* In contrast to the above method, the parent is always the view.
@@ -362,7 +362,7 @@ protected slots:
void slotShowSelected(void);
/**
- * This slot is connected to the KListView executed signal
+ * This slot is connected to the TDEListView executed signal
*/
void slotItemSelected(TQListViewItem *it_v);